@@ -10,10 +10,10 @@ from django.views.generic import View
 
 
 class BackboneAPIView(View):
-    model = None
-    display_fields = []
-    form = None  # The form to be used for adding or editing an object.
-    fields = []  # Fields to allow when adding or editing an object.
+    model = None  # The model to be used for this API definition
+    display_fields = []  # Fields to return for read (GET) requests,
+    fields = []  # Fields to allow when adding (POST) or editing (PUT) objects.
+    form = None  # The form class to be used for adding or editing objects.
     ordering = None  # Ordering used when retrieving the collection
 
     def queryset(self, request):
@@ -75,8 +75,11 @@ class BackboneAPIView(View):
         except ValueError:
             return HttpResponseBadRequest(_('Unable to parse JSON request body.'))
 
-        form = self.get_form(request)(data=data)
+        form = self.get_form_instance(request, data=data)
         if form.is_valid():
+            if not self.has_add_permission_for_data(request, form.cleaned_data):
+                return HttpResponseForbidden(_('You do not have permission to perform this action.'))
+
             obj = form.save()
 
             # We return the newly created object's details and a Location header with it's url
@@ -113,8 +116,10 @@ class BackboneAPIView(View):
         except ValueError:
             return HttpResponseBadRequest(_('Unable to parse JSON request body.'))
 
-        form = self.get_form(request)(instance=obj, data=data)
+        form = self.get_form_instance(request, data=data, instance=obj)
         if form.is_valid():
+            if not self.has_update_permission_for_data(request, form.cleaned_data):
+                return HttpResponseForbidden(_('You do not have permission to perform this action.'))
             form.save()
 
             # We return the updated object details
@@ -122,16 +127,19 @@ class BackboneAPIView(View):
         else:
             return HttpResponseBadRequest(self.json_dumps(form.errors), mimetype='application/json')
 
-    def get_form(self, request):
+    def get_form_instance(self, request, data=None, instance=None):
         """
-        Returns the form to be used for adding or editing an object.
+        Returns an instantiated form to be used for adding or editing an object.
+
+        The `instance` argument is the model instance (passed only if this form
+        is going to be used for editing and existing object).
         """
         defaults = {}
         if self.form:
             defaults['form'] = self.form
         if self.fields:
             defaults['fields'] = self.fields
-        return modelform_factory(self.model, **defaults)
+        return modelform_factory(self.model, **defaults)(data=data, instance=instance)
 
     def delete(self, request, id=None):
         """
@@ -163,6 +171,16 @@ class BackboneAPIView(View):
         )
         return request.user.has_perm(perm_string)
 
+    def has_add_permission_for_data(self, request, cleaned_data):
+        """
+        Returns True if the requesting user is allowed to add an object with the
+        given data, False otherwise.
+
+        If the add permission does not depend on the data being submitted,
+        use `has_add_permission` instead.
+        """
+        return True
+
     def has_update_permission(self, request, obj):
         """
         Returns True if the requesting user is allowed to update the given object, False otherwise.
@@ -172,6 +190,16 @@ class BackboneAPIView(View):
         )
         return request.user.has_perm(perm_string)
 
+    def has_update_permission_for_data(self, request, cleaned_data):
+        """
+        Returns True if the requesting user is allowed to update the object with the
+        given data, False otherwise.
+
+        If the update permission does not depend on the data being submitted,
+        use `has_update_permission` instead.
+        """
+        return True
+
     def has_delete_permission(self, request, obj):
         """
         Returns True if the requesting user is allowed to delete the given object, False otherwise.
